/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * USRP Daughterboard ID's
 */

#ifndef INCLUDED_USRP_DAUGHTERBOARDS_H
#define INCLUDED_USRP_DAUGHTERBOARDS_H

#define	USRP_DBID_BASIC_TX		0x0000
#define	USRP_DBID_BASIC_RX		0x0001
#define USRP_DBID_DBS_RX		0x0002
#define USRP_DBID_TV_RX			0x0003
#define	USRP_DBID_EXPERIMENTAL_TX	0xfffe	// homebrew, etc
#define	USRP_DBID_EXPERIMENTAL_RX	0xffff



#endif /* INCLUDED_USRP_DAUGHTERBOARDS_H */
